@@ -394,6 +394,7 @@ class Albums(ViewContainer):
         self.view = Gtk.FlowBox(homogeneous=True,
                                 hexpand=True,
                                 halign=Gtk.Align.FILL,
+                                valign=Gtk.Align.START,
                                 selection_mode=Gtk.SelectionMode.NONE,
                                 margin=18,
                                 row_spacing=12,
@@ -1299,6 +1300,11 @@ class Playlist(ViewContainer):
 
             self._populate()
 
+    @log
+    def remove_playlist(self):
+        if not self.current_playlist_is_protected():
+            self._on_delete_activate(None)
+
     @log
     def _on_playlist_activated(self, widget, item_id, path):
         _iter = self.playlists_model.get_iter(path)
